Index: trunk/DataCheck/Processing/BuildSequences.sh
===================================================================
--- trunk/DataCheck/Processing/BuildSequences.sh	(revision 15597)
+++ trunk/DataCheck/Processing/BuildSequences.sh	(revision 15598)
@@ -17,5 +17,5 @@
 cd $mars
 
-check1=`root -q -b datacenter/macros/buildseqentriesf.C++\("\"$datapath\""\,"\"$seqpath\""\,1\,kFALSE\) | tee $logfile | intgrep`
+check1=`root -q -b fact/processing/buildseqentries.C+\("\"$datapath\""\,"\"$seqpath\""\,1\,kFALSE\) | tee $logfile | intgrep`
 
 case $check1 in
@@ -25,5 +25,5 @@
         #check="no"
         ;;
    *)   printprocesslog "ERROR buildseqentriesf.C failed (check1=$check1)"
         #check=$check1
         ;;
@@ -25,5 +25,5 @@
         #check="no"
         ;;
-   *)   printprocesslog "ERROR buildseqentriesf.C failed (check1=$check1)"
+   *)   printprocesslog "ERROR buildseqentries.C failed (check1=$check1)"
         #check=$check1
         ;;
